/* 
 * This file is based on :  
 * jQuery googleMap Copyright Dylan Verheul <dylan@dyve.net>
 * Licensed like jQuery, see http://docs.jquery.com/License
 * 
 * Some initial modifications made by Peter Brownell for Code Positive and
 * School of Everything. 
 *
 * We have made some modifications to the original file, but not that many. 
 * There is a good amount of work to do to tie this into Dupal and make
 * it configurable and themeable. 
 * 
 * For now, unless you want to patch the source, there is not all that
 * much to can do to change things. 
 * 
 * Ideas and plans welcome. 
 */
(function($){
  Drupal.behaviors.geomap = {
    attach: function (context, settings) {
      $("#map").googleMap(null,null, 13, { markers: $(".geo"),controls: ["GSmallZoomControl"]});
    }
  }

  $.googleMap = {
    maps: {},
    marker: function(m) {
      if (!m) {
        return null;
      } 
      else if (m.lat == null && m.lng == null) {
        return $.googleMap.marker($.googleMap.readFromGeo(m));
      } 
      else {
      // Instantiate icon with default image & shadow
      var tinyIcon = new GIcon(G_DEFAULT_ICON);      
      var dg = new Boolean();
      dg = false;
      if (m.draggable) {
        if (m.draggable == "true"){
          dg = true;
        }
      }

      // use custom icon if set
      if (m.image == 'null') {
          tinyIcon.image = null;
      } else if (m.image) {
        tinyIcon.image = m.image;
        
        if (m.shadow == 'null'){
          tinyIcon.shadow = null;
        } else if (m.image && m.shadow){
          tinyIcon.shadow = m.shadow;
        }
        
        if (m.transparent == 'null'){
          tinyIcon.transparent = null;
        } else if (m.transparent){
          tinyIcon.transparent = m.transparent;
        }
        
        if(m.iconwidth && m.iconheight){
          tinyIcon.iconSize = new GSize(m.iconwidth, m.iconheight);
          tinyIcon.shadowSize = new GSize(m.iconwidth, m.iconheight);
          
          if(m.iconanchor_x && m.iconanchor_y){
	        tinyIcon.iconAnchor = new GPoint(m.iconanchor_x, m.iconanchor_y);
          }
        }
      } 
      
      markerOptions = { icon:tinyIcon, draggable:dg };
      
      var marker = new GMarker(new GLatLng(m.lat, m.lng), markerOptions );
      if (m.bind) {
          GEvent.addListener(marker, "click", function() {
          marker.openInfoWindowHtml('<div class="geomap-infowindow">'+$(m.bind).html()+'</div>');
        });
      } 
      else if (m.txt) {
        GEvent.addListener(marker, "click", function() {
        marker.openInfoWindowHtml(m.txt);
        });
      }
      if (m.link) {
        GEvent.addListener(marker, "dblclick", function() {
          window.location=m.link; 
        });
      }
      // set plain title for clusters
      marker.titleplain=m.titleplain;
      if (dg) {
        
          GEvent.addListener(marker, "dragend", function() {
            // confirm whether to register a new location
            if (confirm('Pointer icon has been relocated.\nWould you like to update the location information?')){
              var newpoint = marker.getLatLng();
              // alert
				// ("services/location/geonames/latlng/"+m.nid+"/"+m.cckfield+"/"+m.cckfieldindex+"/"+newpoint.lat()+"/"+newpoint.lng()+"/background");
              var domain_name = document.domain;
              // for testing
              if (domain_name == "localhost"){
                domain_name = "localhost/map";
              }
              $.ajax({
                type: "GET",
                url: "http://"+domain_name+"/services/location/geonames/latlng/"+m.nid+"/"+m.cckfield+"/"+m.cckfieldindex+"/"+newpoint.lat()+"/"+newpoint.lng()+"/background",
                error: function(msg){
                  alert( Drupal.t("Sorry, relocation failed."));
                },
                success: function(msg){
                  alert( Drupal.t("Relocation successful."));
                }
              });
          }
          // cancel
          else {
            alert( Drupal.t("Relocation cancelled by user:\n\nPointer icon was moved, but location information was not updated.\nReloading the page will place the icon back to its original location."));
          }
        });
        
        
      }       
      return marker;
    }
  },
  readFromGeo: function(elem) {
	
	/*
	 * The following section maps the geo microformat to JS variables to use in
	 * this object's googleMap function
	 */
    var latElem = $(".latitude", elem)[0];
    var lngElem = $(".longitude", elem)[0];
    var markerElem = null;
    var infowindowElem = null;
    var infowindowtextElem = null;
    var iconElem = null;
    var iconoptions = new Array();
    var nodeElem = $(".node", elem)[0];
    var titlehtml = null;
    var titleplain = null;
    var windowlink = null;
    
    
    if($(".marker", elem)[0]){
	  markerElem = $(".marker", elem)[0];
    }
    
    if (latElem && lngElem) {
      if(nodeElem){
	    if ( $(nodeElem).attr("nid") > 0 ) {
	      windowlink = $(nodeElem).attr("link");
        }
      }
      
      if(markerElem){
	    // marker elements have 2 parts - infowindow and icon
	    if($(".icon", markerElem)[0]){
		  iconElem = $(".icon", markerElem)[0];
		  
		  // read all options: we can only support the following
          $(".option", iconElem).each(function(index) {
	        // there must be a more dynamic way to do this!
	        iconoptions[$(this).attr("name")] = $(this).attr("value");
	      });
	    }
	      
	    if($(".infowindow", markerElem)[0]){
          infowindowElem = $(".infowindow", markerElem)[0];
		  if($(".infowindow-text", infowindowElem)[0]){
	        infowindowtextElem = $(".infowindow-text", infowindowElem)[0];
	        if(infowindowtextElem){
              titleplain = $(infowindowtextElem).html();
              titlehtml = titleplain;
              if(windowlink){ titlehtml = '<a href="'+windowlink+'">'+titlehtml+'</a>'; }
              titlehtml = titlehtml;
            }
          }
        }
      }
      
      return { lat:parseFloat($(latElem).attr("title")), lng:parseFloat($(lngElem).attr("title")), 
               txt:titlehtml, link: windowlink, /* bind: $(elem).attr('bind'), */ 
               image: $(iconElem).attr('src'), iconwidth: iconoptions["iconwidth"], iconheight: iconoptions["iconheight"], iconanchor_x: iconoptions["iconanchor_x"], iconanchor_y: iconoptions["iconanchor_y"], shadow: iconoptions["shadow"], transparent: iconoptions["transparent"], draggable: iconoptions["draggable"], 
               cckfield: $(elem).attr("cckfield"), cckfieldindex: $(elem).attr("cckfieldindex"), nid: $(nodeElem).attr("nid"),
               titleplain: titleplain
             }
    } else {
      return null;
    }
  },
  mapNum: 1
};

 
$.fn.googleMap = function(lat, lng, zoom, options) {
  
  // If we aren't supported, we're done
  if (!window.GBrowserIsCompatible || !GBrowserIsCompatible()) return this;
  
  // Default values make for easy debugging
  if (lat == null) lat = 51.52177;
  if (lng == null) lng = -0.20101;
  if (!zoom) zoom = 1;
  // Sanitize options
  if (!options || typeof options != 'object') options = {};
  options.mapOptions = options.mapOptions || {};
  options.markers = options.markers || [];
  options.controls = options.controls || {};

  // Map all our elements
  return this.each(function() {
	$('#map-loader-image').fadeIn('slow');
	
    // Make sure we have a valid id
    if (!this.id) this.id = "gMap" + $.googleMap.mapNum++;
    // find our markers
    var marker = null;
    var markers = new Array();
    var bounds = null;
    for (var i = 0; i < options.markers.length; i++) {
      if (marker = $.googleMap.marker(options.markers[i])) {
        markers[i] = marker;
        if (!bounds) { 
          var bounds = new GLatLngBounds(marker.getPoint());
        } 
        else {
          // extend bounds with marker.getPoint();
          bounds.extend(marker.getPoint());
        }
      }
    }
    // we only want a map if we have markers
    if (markers.length) {
      // Create a map and a shortcut to it at the same time
	  $(this).addClass('googlemap-display');
      var map = $.googleMap.maps[this.id] = new GMap2(this, options.mapOptions); 
      
      // Center and zoom the map
      map.setCenter(new GLatLng(lat, lng), zoom);
      // Add controls to our map
      for (var i = 0; i < options.controls.length; i++) {
        var c = options.controls[i];
        eval("map.addControl(new " + c + "());");
      }
      for (var i = 0; i < markers.length; i++) {
        map.addOverlay(markers[i]);
        // clusterer.AddMarker( markers[i], markers[i].titleplain );
      }
      // time to zoom the map
      var distance = 0.015;
      if ( markers.length == 1 ) {
        // if we only have one marker, we move out a bit more
        distance = 0.5;
      }
      // Moving the map to show our markers
      // We have to set the centre to get the bounds properly
      
      map.setCenter(bounds.getCenter(), map.getBoundsZoomLevel(bounds));
      var southWest=bounds.getSouthWest();
      var northEast=bounds.getNorthEast();
      bounds.extend(new GLatLng(southWest.lat() - distance, southWest.lng() - distance ));
      bounds.extend(new GLatLng(northEast.lat() + distance, northEast.lng() + distance ));                 
      map.setCenter(bounds.getCenter(), map.getBoundsZoomLevel(bounds));    
      map.enableScrollWheelZoom();
    }
    
	$('#map-loader-image').fadeOut('slow');
  });
};
})(jQuery);